Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(267)

Unified Diff: src/gpu/gl/GrGLContext.h

Issue 133413003: Rename GrGLBinding->GrGLStandard, no longer a bitfield (Closed) Base URL: https://skia.googlecode.com/svn/trunk
Patch Set: actually fix enum names? Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/gpu/gl/GrGLContext.h
diff --git a/src/gpu/gl/GrGLContext.h b/src/gpu/gl/GrGLContext.h
index d2174c56c8c23310cabdaaa0e1f547948da609b1..a418121f49d7b19419f3d24a009a353a7382eae3 100644
--- a/src/gpu/gl/GrGLContext.h
+++ b/src/gpu/gl/GrGLContext.h
@@ -19,7 +19,7 @@
/**
* Encapsulates information about an OpenGL context including the OpenGL
* version, the GrGLBinding type of the context, and GLSL version.
*/
class GrGLContextInfo {
public:
@@ -43,7 +43,7 @@ public:
bool initialize(const GrGLInterface* interface);
bool isInitialized() const;
- GrGLBinding binding() const { return fBindingInUse; }
+ GrGLStandard standard() const { return fStandard; }
GrGLVersion version() const { return fGLVersion; }
GrGLSLGeneration glslGeneration() const { return fGLSLGeneration; }
GrGLVendor vendor() const { return fVendor; }
@@ -75,7 +75,7 @@ public:
private:
- GrGLBinding fBindingInUse;
+ GrGLStandard fStandard;
GrGLVersion fGLVersion;
GrGLSLGeneration fGLSLGeneration;
GrGLVendor fVendor;
@@ -19,7 +19,7 @@
/**
* Encapsulates information about an OpenGL context including the OpenGL
- * version, the GrGLBinding type of the context, and GLSL version.
+ * version, the GrGLStandard type of the context, and GLSL version.
*/
class GrGLContextInfo {
« no previous file with comments | « src/gpu/gl/GrGLCaps.cpp ('k') | src/gpu/gl/GrGLContext.cpp » ('j') | src/gpu/gl/GrGLContext.cpp » ('J')

Powered by Google App Engine
This is Rietveld 408576698